@@ -76,7 +76,7 @@ import Network.Http.Connection
 import Network.Http.RequestBuilder
 import Network.Http.Types
 
-#if defined __LINUX__
+#if defined __LINUX__ || defined __FREEBSD__
 import System.Directory (doesDirectoryExist)
 #endif
 
@@ -240,6 +240,9 @@ baselineContextSSL = do
     SSL.contextSetVerificationMode ctx SSL.VerifyNone
 #elif defined __WINDOWS__
     SSL.contextSetVerificationMode ctx SSL.VerifyNone
+#elif defined __FREEBSD__
+    SSL.contextSetCAFile ctx "/usr/local/etc/ssl/cert.pem"
+    SSL.contextSetVerificationMode ctx $ SSL.VerifyPeer True True Nothing
 #else
     fedora <- doesDirectoryExist "/etc/pki/tls"
     if fedora
@@ -615,4 +618,3 @@ jsonHandler _ i = do
     case r of
         (Success a) ->  return a
         (Error str) ->  error str
-
